@@ -147,7 +147,7 @@ Closees any opened files by us
 sub DESTROY
 {
     my ($self) = @_;
-    close ($self->{' INFILE'});
+    close ($self->{' INFILE'}) if $self->{' INFILE'};
     undef;
 }
 
@@ -169,7 +169,7 @@ Copyright (c) 1998-2013, SIL International (http://www.sil.org)
 This module is released under the terms of the Artistic License 2.0. 
 For details, see the full text of the license in the file LICENSE.
 
-The test suite contains test fonts released under the SIL Open Font License 1.1, see OFL.txt.
+
 
 =cut
 
